@@ -27,7 +27,6 @@ from redis.commands.search.suggestion import Suggestion
 
 from .conftest import (
     _get_client,
-    assert_resp_response,
     is_resp2_connection,
     skip_if_redis_enterprise,
     skip_if_resp_version,
@@ -893,7 +892,7 @@ def test_dict_operations(client):
 
     # Dump dict and inspect content
     res = client.ft().dict_dump("custom_dict")
-    assert_resp_response(client, res, ["item1", "item3"], {"item1", "item3"})
+    assert res == ["item1", "item3"]
 
     # Remove rest of the items before reload
     client.ft().dict_del("custom_dict", *res)
@@ -1385,16 +1384,14 @@ def test_aggregations_apply(client):
     )
     res = client.ft().aggregate(req)
     if is_resp2_connection(client):
-        res_set = set([res.rows[0][1], res.rows[1][1]])
-        assert res_set == set(["6373878785249699840", "6373878758592700416"])
+        res_set = {res.rows[0][1], res.rows[1][1]}
+        assert res_set == {"6373878785249699840", "6373878758592700416"}
     else:
-        res_set = set(
-            [
-                res["results"][0]["extra_attributes"]["CreatedDateTimeUTC"],
-                res["results"][1]["extra_attributes"]["CreatedDateTimeUTC"],
-            ],
-        )
-        assert res_set == set(["6373878785249699840", "6373878758592700416"])
+        res_set = {
+            res["results"][0]["extra_attributes"]["CreatedDateTimeUTC"],
+            res["results"][1]["extra_attributes"]["CreatedDateTimeUTC"],
+        }
+        assert res_set == {"6373878785249699840", "6373878758592700416"}
 
 
 @pytest.mark.redismod
@@ -1469,6 +1466,61 @@ def test_aggregations_add_scores(client):
         assert res.rows[1] == ["__score", "0.2"]
 
 
+@pytest.mark.redismod
+@skip_ifmodversion_lt("2.10.05", "search")
+async def test_aggregations_hybrid_scoring(client):
+    client.ft().create_index(
+        (
+            TextField("name", sortable=True, weight=5.0),
+            TextField("description", sortable=True, weight=5.0),
+            VectorField(
+                "vector",
+                "HNSW",
+                {"TYPE": "FLOAT32", "DIM": 2, "DISTANCE_METRIC": "COSINE"},
+            ),
+        )
+    )
+
+    client.hset(
+        "doc1",
+        mapping={
+            "name": "cat book",
+            "description": "an animal book about cats",
+            "vector": np.array([0.1, 0.2]).astype(np.float32).tobytes(),
+        },
+    )
+    client.hset(
+        "doc2",
+        mapping={
+            "name": "dog book",
+            "description": "an animal book about dogs",
+            "vector": np.array([0.2, 0.1]).astype(np.float32).tobytes(),
+        },
+    )
+
+    query_string = "(@description:animal)=>[KNN 3 @vector $vec_param AS dist]"
+    req = (
+        aggregations.AggregateRequest(query_string)
+        .scorer("BM25")
+        .add_scores()
+        .apply(hybrid_score="@__score + @dist")
+        .load("*")
+        .dialect(4)
+    )
+
+    res = client.ft().aggregate(
+        req,
+        query_params={"vec_param": np.array([0.11, 0.21]).astype(np.float32).tobytes()},
+    )
+
+    if isinstance(res, dict):
+        assert len(res["results"]) == 2
+    else:
+        assert len(res.rows) == 2
+        for row in res.rows:
+            len(row) == 6
+
+
 @pytest.mark.redismod
 @skip_ifmodversion_lt("2.0.0", "search")
 def test_index_definition(client):
@@ -2175,7 +2227,7 @@ def test_numeric_params(client):
 @pytest.mark.redismod
 @skip_ifmodversion_lt("2.4.3", "search")
 def test_geo_params(client):
-    client.ft().create_index((GeoField("g")))
+    client.ft().create_index(GeoField("g"))
     client.hset("doc1", mapping={"g": "29.69465, 34.95126"})
     client.hset("doc2", mapping={"g": "29.69350, 34.94737"})
     client.hset("doc3", mapping={"g": "29.68746, 34.94882"})
@@ -2348,14 +2400,14 @@ def test_withsuffixtrie(client: redis.Redis):
         assert client.ft().dropindex("idx")
 
         # create withsuffixtrie index (text fields)
-        assert client.ft().create_index((TextField("t", withsuffixtrie=True)))
+        assert client.ft().create_index(TextField("t", withsuffixtrie=True))
         waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
         info = client.ft().info()
         assert "WITHSUFFIXTRIE" in info["attributes"][0]
         assert client.ft().dropindex("idx")
 
         # create withsuffixtrie index (tag field)
-        assert client.ft().create_index((TagField("t", withsuffixtrie=True)))
+        assert client.ft().create_index(TagField("t", withsuffixtrie=True))
         waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
         info = client.ft().info()
         assert "WITHSUFFIXTRIE" in info["attributes"][0]
@@ -2365,14 +2417,14 @@ def test_withsuffixtrie(client: redis.Redis):
         assert client.ft().dropindex("idx")
 
         # create withsuffixtrie index (text fields)
-        assert client.ft().create_index((TextField("t", withsuffixtrie=True)))
+        assert client.ft().create_index(TextField("t", withsuffixtrie=True))
         waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
         info = client.ft().info()
         assert "WITHSUFFIXTRIE" in info["attributes"][0]["flags"]
         assert client.ft().dropindex("idx")
 
         # create withsuffixtrie index (tag field)
-        assert client.ft().create_index((TagField("t", withsuffixtrie=True)))
+        assert client.ft().create_index(TagField("t", withsuffixtrie=True))
         waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
         info = client.ft().info()
         assert "WITHSUFFIXTRIE" in info["attributes"][0]["flags"]
@@ -2391,7 +2443,7 @@ def test_query_timeout(r: redis.Redis):
 
 @pytest.mark.redismod
 def test_geoshape(client: redis.Redis):
-    client.ft().create_index((GeoShapeField("geom", GeoShapeField.FLAT)))
+    client.ft().create_index(GeoShapeField("geom", GeoShapeField.FLAT))
     waitForIndex(client, getattr(client.ft(), "index_name", "idx"))
     client.hset("small", "geom", "POLYGON((1 1, 1 100, 100 100, 100 1, 1 1))")
     client.hset("large", "geom", "POLYGON((1 1, 1 200, 200 200, 200 1, 1 1))")
